@@ -56,9 +56,13 @@
         <translation type="obsolete">cuteTube-QML - 0.7.3 in deutsch</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.7.5</source>
-        <translation>cuteTube-QML - 0.7.5 in deutsch</translation>
+        <translation type="obsolete">cuteTube-QML - 0.7.5 in deutsch</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.7.6</source>
+        <translation type="unfinished">cuteTube-QML - 0.7.6 in deutsch</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -183,13 +187,13 @@
         <translation type="obsolete">Vom Gerät löschen</translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="33"/>
+        <location filename="../ArchiveListView.qml" line="49"/>
         <source>Deleted from archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="36"/>
-        <location filename="../ArchiveListView.qml" line="53"/>
+        <location filename="../ArchiveListView.qml" line="52"/>
+        <location filename="../ArchiveListView.qml" line="69"/>
         <source>Unable to delete from archive</source>
         <translation type="unfinished"></translation>
     </message>
@@ -395,7 +399,7 @@
         <translation type="obsolete">Beenden</translation>
     </message>
     <message>
-        <location filename="../MenuBar.qml" line="130"/>
+        <location filename="../MenuBar.qml" line="133"/>
         <source>Sort</source>
         <translation type="unfinished"></translation>
     </message>
@@ -495,12 +499,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="51"/>
+        <location filename="../NotificationArea.qml" line="52"/>
         <source>No active downloads</source>
         <translation>Keine aktiven Downloads</translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="146"/>
+        <location filename="../NotificationArea.qml" line="147"/>
         <source>Downloads</source>
         <translation>Downloads</translation>
     </message>
@@ -558,12 +562,12 @@
         <translation type="obsolete">In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="59"/>
+        <location filename="../PlaylistVideosView.qml" line="69"/>
         <source>Video(s) deleted from playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="80"/>
+        <location filename="../PlaylistVideosView.qml" line="90"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
@@ -626,7 +630,7 @@
         <translation>Aufrufe</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="181"/>
+        <location filename="../SearchBar.qml" line="182"/>
         <source>Order by:</source>
         <translation>Sortieren nach:</translation>
     </message>
@@ -1218,12 +1222,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="117"/>
+        <location filename="../UserVideosView.qml" line="129"/>
         <source>You have subscribed to &apos;</source>
         <translation>Du hast ein Abonnement bei</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="121"/>
+        <location filename="../UserVideosView.qml" line="133"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Abonnement gekündigt bei</translation>
     </message>
@@ -1252,27 +1256,27 @@
         <translation type="obsolete">In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="141"/>
+        <location filename="../UserVideosView.qml" line="153"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="200"/>
+        <location filename="../UserVideosView.qml" line="212"/>
         <source>Subscribers</source>
         <translation>Abonnenten</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="214"/>
+        <location filename="../UserVideosView.qml" line="226"/>
         <source>Videos</source>
         <translation>Videos</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="237"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Unsubscribe</source>
         <translation>Abonnement kündigen</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="237"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Subscribe</source>
         <translation>Abonnieren</translation>
     </message>
@@ -1430,12 +1434,12 @@
         <translation type="obsolete">In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="70"/>
+        <location filename="../VideoListView.qml" line="86"/>
         <source>Video(s) deleted from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="92"/>
+        <location filename="../VideoListView.qml" line="108"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
@@ -1556,34 +1560,35 @@
         <translation>Bei YouTube angemeldet als &apos;</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="121"/>
-        <location filename="../../../youtube.cpp" line="227"/>
+        <location filename="../../../youtube.cpp" line="164"/>
+        <location filename="../../../youtube.cpp" line="270"/>
         <source>Error - Server repsonse is: </source>
         <translation>Fehler - Serverantwort ist:</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="171"/>
-        <location filename="../../../youtube.cpp" line="179"/>
+        <location filename="../../../youtube.cpp" line="214"/>
+        <location filename="../../../youtube.cpp" line="222"/>
         <source>Upload aborted</source>
         <translation>Upload abgebrochen</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="186"/>
+        <location filename="../../../youtube.cpp" line="229"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Upload unterbrochen. Versuche wiederaufnahme...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="190"/>
+        <location filename="../../../youtube.cpp" line="233"/>
         <source>Upload failed</source>
         <translation>Upload fehlgeschlagen</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="196"/>
+        <location filename="../../../youtube.cpp" line="239"/>
         <source>Upload is completed</source>
         <translation>Upload ist komplett</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="388"/>
+        <location filename="../../../youtube.cpp" line="437"/>
+        <location filename="../../../youtube.cpp" line="479"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Fehler: Kann Video nicht empfangen</translation>
     </message>
@@ -1619,14 +1624,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="160"/>
         <source>Video added to favourites</source>
-        <translation>Video wurde zu Favoriten hinzugefügt</translation>
+        <translation type="obsolete">Video wurde zu Favoriten hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="161"/>
         <source>Video added to playlist</source>
-        <translation>Video wurde zur Wiedergabeliste hinzugefügt</translation>
+        <translation type="obsolete">Video wurde zur Wiedergabeliste hinzugefügt</translation>
     </message>
     <message>
         <location filename="../main.qml" line="169"/>
@@ -1643,6 +1646,16 @@
         <source>Conversion of &apos;</source>
         <translation>Unterhaltung zwischen &apos;</translation>
     </message>
+    <message>
+        <location filename="../main.qml" line="160"/>
+        <source>Video(s) added to favourites</source>
+        <translation>Video(s) wurde zu Favoriten hinzugefügt</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="161"/>
+        <source>Video(s) added to playlist</source>
+        <translation>Video(s) wurde zur Wiedergabeliste hinzugefügt</translation>
+    </message>
     <message>
         <location filename="../main.qml" line="219"/>
         <source>&apos; failed</source>
@@ -1677,12 +1690,12 @@
         <translation>Fehlgeschlagen</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="416"/>
+        <location filename="../main.qml" line="417"/>
         <source>Most Recent</source>
         <translation>Aktuellste Videos</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="417"/>
+        <location filename="../main.qml" line="418"/>
         <source>Most Viewed</source>
         <translation>Meistgesehen</translation>
     </message>
