@@ -36,9 +36,13 @@
         <translation type="obsolete">cuteTube-QML - 0.7.3 - Suomennos: d-iivil</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.7.5</source>
-        <translation type="unfinished">cuteTube-QML - 0.7.5 - Suomennos: d-iivil</translation>
+        <translation type="obsolete">cuteTube-QML - 0.7.5 - Suomennos: d-iivil</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.7.6</source>
+        <translation type="unfinished">cuteTube-QML - 0.7.6 - Suomennos: d-iivil</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -139,13 +143,13 @@
         <translation type="obsolete">Poista laitteesta</translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="33"/>
+        <location filename="../ArchiveListView.qml" line="49"/>
         <source>Deleted from archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="36"/>
-        <location filename="../ArchiveListView.qml" line="53"/>
+        <location filename="../ArchiveListView.qml" line="52"/>
+        <location filename="../ArchiveListView.qml" line="69"/>
         <source>Unable to delete from archive</source>
         <translation type="unfinished"></translation>
     </message>
@@ -339,7 +343,7 @@
         <translation type="obsolete">Poistu</translation>
     </message>
     <message>
-        <location filename="../MenuBar.qml" line="130"/>
+        <location filename="../MenuBar.qml" line="133"/>
         <source>Sort</source>
         <translation type="unfinished"></translation>
     </message>
@@ -435,12 +439,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="51"/>
+        <location filename="../NotificationArea.qml" line="52"/>
         <source>No active downloads</source>
         <translation>Ei aktiivisia latauksia</translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="146"/>
+        <location filename="../NotificationArea.qml" line="147"/>
         <source>Downloads</source>
         <translation>Lataukset</translation>
     </message>
@@ -498,12 +502,12 @@
         <translation type="obsolete">Kopioi leikepöydälle</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="59"/>
+        <location filename="../PlaylistVideosView.qml" line="69"/>
         <source>Video(s) deleted from playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="80"/>
+        <location filename="../PlaylistVideosView.qml" line="90"/>
         <source>No videos found</source>
         <translation>Ei videoita</translation>
     </message>
@@ -566,7 +570,7 @@
         <translation>Katseluja</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="181"/>
+        <location filename="../SearchBar.qml" line="182"/>
         <source>Order by:</source>
         <translation>Järjestä: </translation>
     </message>
@@ -1150,12 +1154,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="117"/>
+        <location filename="../UserVideosView.qml" line="129"/>
         <source>You have subscribed to &apos;</source>
         <translation>Olet tilannut syötteen: </translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="121"/>
+        <location filename="../UserVideosView.qml" line="133"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Olet perunut syötteen: </translation>
     </message>
@@ -1184,27 +1188,27 @@
         <translation type="obsolete">Kopioi leikepöydälle</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="141"/>
+        <location filename="../UserVideosView.qml" line="153"/>
         <source>No videos found</source>
         <translation>Ei videoita</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="200"/>
+        <location filename="../UserVideosView.qml" line="212"/>
         <source>Subscribers</source>
         <translation>Tilaajat</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="214"/>
+        <location filename="../UserVideosView.qml" line="226"/>
         <source>Videos</source>
         <translation>Videot</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="237"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Unsubscribe</source>
         <translation>Peru tilaus</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="237"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Subscribe</source>
         <translation>Tilaa</translation>
     </message>
@@ -1362,12 +1366,12 @@
         <translation type="obsolete">Kopioi leikepöydälle</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="70"/>
+        <location filename="../VideoListView.qml" line="86"/>
         <source>Video(s) deleted from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="92"/>
+        <location filename="../VideoListView.qml" line="108"/>
         <source>No videos found</source>
         <translation>Ei videoita</translation>
     </message>
@@ -1488,34 +1492,35 @@
         <translation>Olet kirjautunut YouTubeen tilillä: </translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="121"/>
-        <location filename="../../../youtube.cpp" line="227"/>
+        <location filename="../../../youtube.cpp" line="164"/>
+        <location filename="../../../youtube.cpp" line="270"/>
         <source>Error - Server repsonse is: </source>
         <translation>Virhe - Palvelin vastasi: </translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="171"/>
-        <location filename="../../../youtube.cpp" line="179"/>
+        <location filename="../../../youtube.cpp" line="214"/>
+        <location filename="../../../youtube.cpp" line="222"/>
         <source>Upload aborted</source>
         <translation>Lataus keskeytetty</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="186"/>
+        <location filename="../../../youtube.cpp" line="229"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Lataus keskeytyi. Kokeilen jatkaa...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="190"/>
+        <location filename="../../../youtube.cpp" line="233"/>
         <source>Upload failed</source>
         <translation>Lataus epäonnistui</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="196"/>
+        <location filename="../../../youtube.cpp" line="239"/>
         <source>Upload is completed</source>
         <translation>Lataus valmistui</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="388"/>
+        <location filename="../../../youtube.cpp" line="437"/>
+        <location filename="../../../youtube.cpp" line="479"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Virhe: videon lataus epäonnistui</translation>
     </message>
@@ -1551,14 +1556,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="160"/>
         <source>Video added to favourites</source>
-        <translation>Video lisätty suosikkeihin</translation>
+        <translation type="obsolete">Video lisätty suosikkeihin</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="161"/>
         <source>Video added to playlist</source>
-        <translation>Video lisätty soittolistalle</translation>
+        <translation type="obsolete">Video lisätty soittolistalle</translation>
     </message>
     <message>
         <location filename="../main.qml" line="169"/>
@@ -1575,6 +1578,16 @@
         <source>Conversion of &apos;</source>
         <translation>Muunto: </translation>
     </message>
+    <message>
+        <location filename="../main.qml" line="160"/>
+        <source>Video(s) added to favourites</source>
+        <translation>Video(t) lisätty suosikkeihin</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="161"/>
+        <source>Video(s) added to playlist</source>
+        <translation>Video(t) lisätty soittolistalle</translation>
+    </message>
     <message>
         <location filename="../main.qml" line="219"/>
         <source>&apos; failed</source>
@@ -1605,12 +1618,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="416"/>
+        <location filename="../main.qml" line="417"/>
         <source>Most Recent</source>
         <translation>Tuoreimmat</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="417"/>
+        <location filename="../main.qml" line="418"/>
         <source>Most Viewed</source>
         <translation>Katsotuimmat</translation>
     </message>
