@@ -9,7 +9,7 @@
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.7.5</source>
+        <source>cuteTube-QML - 0.7.6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -107,13 +107,13 @@
         <translation type="obsolete">Verwijder van toestel</translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="33"/>
+        <location filename="../ArchiveListView.qml" line="49"/>
         <source>Deleted from archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="36"/>
-        <location filename="../ArchiveListView.qml" line="53"/>
+        <location filename="../ArchiveListView.qml" line="52"/>
+        <location filename="../ArchiveListView.qml" line="69"/>
         <source>Unable to delete from archive</source>
         <translation type="unfinished"></translation>
     </message>
@@ -303,7 +303,7 @@
         <translation type="obsolete">Afsluiten</translation>
     </message>
     <message>
-        <location filename="../MenuBar.qml" line="130"/>
+        <location filename="../MenuBar.qml" line="133"/>
         <source>Sort</source>
         <translation type="unfinished"></translation>
     </message>
@@ -395,12 +395,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="51"/>
+        <location filename="../NotificationArea.qml" line="52"/>
         <source>No active downloads</source>
         <translation>Geen actieve downloads</translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="146"/>
+        <location filename="../NotificationArea.qml" line="147"/>
         <source>Downloads</source>
         <translation></translation>
     </message>
@@ -446,12 +446,12 @@
         <translation type="obsolete">Kopiëren naar klembord</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="59"/>
+        <location filename="../PlaylistVideosView.qml" line="69"/>
         <source>Video(s) deleted from playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="80"/>
+        <location filename="../PlaylistVideosView.qml" line="90"/>
         <source>No videos found</source>
         <translation>Geen video&apos;s gevonden</translation>
     </message>
@@ -514,7 +514,7 @@
         <translation>Bekenen</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="181"/>
+        <location filename="../SearchBar.qml" line="182"/>
         <source>Order by:</source>
         <translation>Sorteren op:</translation>
     </message>
@@ -1098,12 +1098,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="117"/>
+        <location filename="../UserVideosView.qml" line="129"/>
         <source>You have subscribed to &apos;</source>
         <translation>U heeft zich aangemeld voor &apos;</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="121"/>
+        <location filename="../UserVideosView.qml" line="133"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>U heeft zich afgemeld voor &apos;</translation>
     </message>
@@ -1120,27 +1120,27 @@
         <translation type="obsolete">Kopiëren naar klembord</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="141"/>
+        <location filename="../UserVideosView.qml" line="153"/>
         <source>No videos found</source>
         <translation>Geen videos gevonden</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="200"/>
+        <location filename="../UserVideosView.qml" line="212"/>
         <source>Subscribers</source>
         <translation>Abonnees</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="214"/>
+        <location filename="../UserVideosView.qml" line="226"/>
         <source>Videos</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="237"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Unsubscribe</source>
         <translation>Afmelden</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="237"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Subscribe</source>
         <translation>Aanmelden</translation>
     </message>
@@ -1286,12 +1286,12 @@
         <translation type="obsolete">Kopiëren naar het klembord</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="70"/>
+        <location filename="../VideoListView.qml" line="86"/>
         <source>Video(s) deleted from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="92"/>
+        <location filename="../VideoListView.qml" line="108"/>
         <source>No videos found</source>
         <translation>Geen video&apos;s gevonden</translation>
     </message>
@@ -1328,34 +1328,35 @@
         <translation>U bent aangemeld bij YouTube als &apos;</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="121"/>
-        <location filename="../../../youtube.cpp" line="227"/>
+        <location filename="../../../youtube.cpp" line="164"/>
+        <location filename="../../../youtube.cpp" line="270"/>
         <source>Error - Server repsonse is: </source>
         <translation>Error - Server antwoord is:</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="171"/>
-        <location filename="../../../youtube.cpp" line="179"/>
+        <location filename="../../../youtube.cpp" line="214"/>
+        <location filename="../../../youtube.cpp" line="222"/>
         <source>Upload aborted</source>
         <translation>Upload gestopt</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="186"/>
+        <location filename="../../../youtube.cpp" line="229"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Upload onderbroken. Probeert te hervatten ...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="190"/>
+        <location filename="../../../youtube.cpp" line="233"/>
         <source>Upload failed</source>
         <translation>Upload mislukt</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="196"/>
+        <location filename="../../../youtube.cpp" line="239"/>
         <source>Upload is completed</source>
         <translation>Upload is voltooid</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="388"/>
+        <location filename="../../../youtube.cpp" line="437"/>
+        <location filename="../../../youtube.cpp" line="479"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Fout: Kan geen video ophalen</translation>
     </message>
@@ -1391,14 +1392,12 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="160"/>
         <source>Video added to favourites</source>
-        <translation>Video toe gevoegd aan favorieten</translation>
+        <translation type="obsolete">Video toe gevoegd aan favorieten</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="161"/>
         <source>Video added to playlist</source>
-        <translation>Video toe gevoegd aan afspeellijst</translation>
+        <translation type="obsolete">Video toe gevoegd aan afspeellijst</translation>
     </message>
     <message>
         <location filename="../main.qml" line="169"/>
@@ -1415,6 +1414,16 @@
         <source>Conversion of &apos;</source>
         <translation>Conversie van &apos;</translation>
     </message>
+    <message>
+        <location filename="../main.qml" line="160"/>
+        <source>Video(s) added to favourites</source>
+        <translation>Video(s) toe gevoegd aan favorieten</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="161"/>
+        <source>Video(s) added to playlist</source>
+        <translation>Video(s) toe gevoegd aan afspeellijst</translation>
+    </message>
     <message>
         <location filename="../main.qml" line="219"/>
         <source>&apos; failed</source>
@@ -1445,12 +1454,12 @@
         <translation>Mislukt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="416"/>
+        <location filename="../main.qml" line="417"/>
         <source>Most Recent</source>
         <translation>Meest Recent</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="417"/>
+        <location filename="../main.qml" line="418"/>
         <source>Most Viewed</source>
         <translation>Meest Bekeken</translation>
     </message>
