@@ -32,9 +32,13 @@
         <translation type="obsolete">cuteTube-QML - 0.7.3 - PL</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.7.5</source>
-        <translation type="unfinished">cuteTube-QML - 0.7.5 - PL</translation>
+        <translation type="obsolete">cuteTube-QML - 0.7.5 - PL</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.7.6</source>
+        <translation type="unfinished">cuteTube-QML - 0.7.6 - PL</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -135,13 +139,13 @@
         <translation type="obsolete">Usuń z urządzenia</translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="33"/>
+        <location filename="../ArchiveListView.qml" line="49"/>
         <source>Deleted from archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="36"/>
-        <location filename="../ArchiveListView.qml" line="53"/>
+        <location filename="../ArchiveListView.qml" line="52"/>
+        <location filename="../ArchiveListView.qml" line="69"/>
         <source>Unable to delete from archive</source>
         <translation type="unfinished"></translation>
     </message>
@@ -323,7 +327,7 @@
         <translation type="obsolete">Wyjście</translation>
     </message>
     <message>
-        <location filename="../MenuBar.qml" line="130"/>
+        <location filename="../MenuBar.qml" line="133"/>
         <source>Sort</source>
         <translation type="unfinished"></translation>
     </message>
@@ -419,12 +423,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="51"/>
+        <location filename="../NotificationArea.qml" line="52"/>
         <source>No active downloads</source>
         <translation>Brak aktywnych pobrań </translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="146"/>
+        <location filename="../NotificationArea.qml" line="147"/>
         <source>Downloads</source>
         <translation>Pobrania</translation>
     </message>
@@ -482,12 +486,12 @@
         <translation type="obsolete">Skopiuj do schowka</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="59"/>
+        <location filename="../PlaylistVideosView.qml" line="69"/>
         <source>Video(s) deleted from playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="80"/>
+        <location filename="../PlaylistVideosView.qml" line="90"/>
         <source>No videos found</source>
         <translation>Nie znaleziono plików wideo</translation>
     </message>
@@ -550,7 +554,7 @@
         <translation>Wyświetlenia</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="181"/>
+        <location filename="../SearchBar.qml" line="182"/>
         <source>Order by:</source>
         <translation>Stortuj po:</translation>
     </message>
@@ -1134,12 +1138,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="117"/>
+        <location filename="../UserVideosView.qml" line="129"/>
         <source>You have subscribed to &apos;</source>
         <translation>Zasubskrybowałeś się do &apos;</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="121"/>
+        <location filename="../UserVideosView.qml" line="133"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Anulowałeś subskrybcje &apos;</translation>
     </message>
@@ -1168,27 +1172,27 @@
         <translation type="obsolete">Skopiuj do schowka</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="141"/>
+        <location filename="../UserVideosView.qml" line="153"/>
         <source>No videos found</source>
         <translation>Brak plików wideo</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="200"/>
+        <location filename="../UserVideosView.qml" line="212"/>
         <source>Subscribers</source>
         <translation>Subskrybenci</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="214"/>
+        <location filename="../UserVideosView.qml" line="226"/>
         <source>Videos</source>
         <translation>Pliki wideo</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="237"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Unsubscribe</source>
         <translation>Wypisz z subskrybcji</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="237"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Subscribe</source>
         <translation>Zapisz do subskrybcji</translation>
     </message>
@@ -1346,12 +1350,12 @@
         <translation type="obsolete">Skopiuj do schowka</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="70"/>
+        <location filename="../VideoListView.qml" line="86"/>
         <source>Video(s) deleted from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="92"/>
+        <location filename="../VideoListView.qml" line="108"/>
         <source>No videos found</source>
         <translation>Brak plików wideo</translation>
     </message>
@@ -1381,34 +1385,35 @@
         <translation>Jesteś zalogowany do YouTube jako &apos;</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="121"/>
-        <location filename="../../../youtube.cpp" line="227"/>
+        <location filename="../../../youtube.cpp" line="164"/>
+        <location filename="../../../youtube.cpp" line="270"/>
         <source>Error - Server repsonse is: </source>
         <translation>Błąd - Serwer odpowiedział:</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="171"/>
-        <location filename="../../../youtube.cpp" line="179"/>
+        <location filename="../../../youtube.cpp" line="214"/>
+        <location filename="../../../youtube.cpp" line="222"/>
         <source>Upload aborted</source>
         <translation>Wysyłanie anulowane</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="186"/>
+        <location filename="../../../youtube.cpp" line="229"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Wysyłanie przerwane. Próba wznowienia...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="190"/>
+        <location filename="../../../youtube.cpp" line="233"/>
         <source>Upload failed</source>
         <translation>Wysyłanie nie udane</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="196"/>
+        <location filename="../../../youtube.cpp" line="239"/>
         <source>Upload is completed</source>
         <translation>Wysyłanie ukończone</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="388"/>
+        <location filename="../../../youtube.cpp" line="437"/>
+        <location filename="../../../youtube.cpp" line="479"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Błąd: Nie można odebrać wideo</translation>
     </message>
@@ -1444,14 +1449,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="160"/>
         <source>Video added to favourites</source>
-        <translation>Wideo dodane do ulubionych</translation>
+        <translation type="obsolete">Wideo dodane do ulubionych</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="161"/>
         <source>Video added to playlist</source>
-        <translation>Wideo dodane do listy odtwarzania</translation>
+        <translation type="obsolete">Wideo dodane do listy odtwarzania</translation>
     </message>
     <message>
         <location filename="../main.qml" line="169"/>
@@ -1468,6 +1471,16 @@
         <source>Conversion of &apos;</source>
         <translation>Konwersja &apos;</translation>
     </message>
+    <message>
+        <location filename="../main.qml" line="160"/>
+        <source>Video(s) added to favourites</source>
+        <translation>Wideo(i) dodane do ulubionych</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="161"/>
+        <source>Video(s) added to playlist</source>
+        <translation>Wideo(i) dodane do listy odtwarzania</translation>
+    </message>
     <message>
         <location filename="../main.qml" line="219"/>
         <source>&apos; failed</source>
@@ -1498,12 +1511,12 @@
         <translation>Nieudany</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="416"/>
+        <location filename="../main.qml" line="417"/>
         <source>Most Recent</source>
         <translation>Ostatnio dodane</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="417"/>
+        <location filename="../main.qml" line="418"/>
         <source>Most Viewed</source>
         <translation>Najczęściej oglądane</translation>
     </message>
