@@ -24,9 +24,13 @@
         <translation type="obsolete">cuteTube-QML - 0.7.3</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.7.5</source>
-        <translation type="unfinished">cuteTube-QML - 0.7.5</translation>
+        <translation type="obsolete">cuteTube-QML - 0.7.5</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.7.6</source>
+        <translation type="unfinished">cuteTube-QML - 0.7.6</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -127,13 +131,13 @@
         <translation type="obsolete">Удалить с устройства</translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="33"/>
+        <location filename="../ArchiveListView.qml" line="49"/>
         <source>Deleted from archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="36"/>
-        <location filename="../ArchiveListView.qml" line="53"/>
+        <location filename="../ArchiveListView.qml" line="52"/>
+        <location filename="../ArchiveListView.qml" line="69"/>
         <source>Unable to delete from archive</source>
         <translation type="unfinished"></translation>
     </message>
@@ -323,7 +327,7 @@
         <translation type="obsolete">Выход</translation>
     </message>
     <message>
-        <location filename="../MenuBar.qml" line="130"/>
+        <location filename="../MenuBar.qml" line="133"/>
         <source>Sort</source>
         <translation type="unfinished"></translation>
     </message>
@@ -419,12 +423,12 @@
 <context>
     <name>NotificationArea</name>
     <message>
-        <location filename="../NotificationArea.qml" line="51"/>
+        <location filename="../NotificationArea.qml" line="52"/>
         <source>No active downloads</source>
         <translation>Нет активных загрузок</translation>
     </message>
     <message>
-        <location filename="../NotificationArea.qml" line="146"/>
+        <location filename="../NotificationArea.qml" line="147"/>
         <source>Downloads</source>
         <translation>Загрузки</translation>
     </message>
@@ -482,12 +486,12 @@
         <translation type="obsolete">Скопировать в буфер</translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="59"/>
+        <location filename="../PlaylistVideosView.qml" line="69"/>
         <source>Video(s) deleted from playlist</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../PlaylistVideosView.qml" line="80"/>
+        <location filename="../PlaylistVideosView.qml" line="90"/>
         <source>No videos found</source>
         <translation>Видео не найдено</translation>
     </message>
@@ -550,7 +554,7 @@
         <translation>Просмотрам</translation>
     </message>
     <message>
-        <location filename="../SearchBar.qml" line="181"/>
+        <location filename="../SearchBar.qml" line="182"/>
         <source>Order by:</source>
         <translation>Сортировать по:</translation>
     </message>
@@ -1134,12 +1138,12 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="117"/>
+        <location filename="../UserVideosView.qml" line="129"/>
         <source>You have subscribed to &apos;</source>
         <translation>Вы подписались на &apos;</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="121"/>
+        <location filename="../UserVideosView.qml" line="133"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Вы больше не подписаны на &apos;</translation>
     </message>
@@ -1168,27 +1172,27 @@
         <translation type="obsolete">Копировать в буфер</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="141"/>
+        <location filename="../UserVideosView.qml" line="153"/>
         <source>No videos found</source>
         <translation>Видео не найдено</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="200"/>
+        <location filename="../UserVideosView.qml" line="212"/>
         <source>Subscribers</source>
         <translation>Подписчики</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="214"/>
+        <location filename="../UserVideosView.qml" line="226"/>
         <source>Videos</source>
         <translation>Видео</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="237"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Unsubscribe</source>
         <translation>Отписаться</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="237"/>
+        <location filename="../UserVideosView.qml" line="249"/>
         <source>Subscribe</source>
         <translation>Подписаться</translation>
     </message>
@@ -1346,12 +1350,12 @@
         <translation type="obsolete">Копировать в буфер</translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="70"/>
+        <location filename="../VideoListView.qml" line="86"/>
         <source>Video(s) deleted from favourites</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../VideoListView.qml" line="92"/>
+        <location filename="../VideoListView.qml" line="108"/>
         <source>No videos found</source>
         <translation>Видео не найдены</translation>
     </message>
@@ -1388,34 +1392,35 @@
         <translation>Вы вошли на YouTube как &apos;</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="121"/>
-        <location filename="../../../youtube.cpp" line="227"/>
+        <location filename="../../../youtube.cpp" line="164"/>
+        <location filename="../../../youtube.cpp" line="270"/>
         <source>Error - Server repsonse is: </source>
         <translation>Ошибка - Ответ сервера:</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="171"/>
-        <location filename="../../../youtube.cpp" line="179"/>
+        <location filename="../../../youtube.cpp" line="214"/>
+        <location filename="../../../youtube.cpp" line="222"/>
         <source>Upload aborted</source>
         <translation>Загрузка отменена</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="186"/>
+        <location filename="../../../youtube.cpp" line="229"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Загрузка прервана. Попытка возобновить...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="190"/>
+        <location filename="../../../youtube.cpp" line="233"/>
         <source>Upload failed</source>
         <translation>Ошибка загрузки</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="196"/>
+        <location filename="../../../youtube.cpp" line="239"/>
         <source>Upload is completed</source>
         <translation>Загрузка завершена</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="388"/>
+        <location filename="../../../youtube.cpp" line="437"/>
+        <location filename="../../../youtube.cpp" line="479"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Ошибка: Невозможно получить видео</translation>
     </message>
@@ -1451,14 +1456,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="160"/>
         <source>Video added to favourites</source>
-        <translation>Видео добавлено в избранное</translation>
+        <translation type="obsolete">Видео добавлено в избранное</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="161"/>
         <source>Video added to playlist</source>
-        <translation>Видео добавлено в плейлист</translation>
+        <translation type="obsolete">Видео добавлено в плейлист</translation>
     </message>
     <message>
         <location filename="../main.qml" line="169"/>
@@ -1475,6 +1478,16 @@
         <source>Conversion of &apos;</source>
         <translation>Конвертация &apos;</translation>
     </message>
+    <message>
+        <location filename="../main.qml" line="160"/>
+        <source>Video(s) added to favourites</source>
+        <translation>Видео добавлено в избранное</translation>
+    </message>
+    <message>
+        <location filename="../main.qml" line="161"/>
+        <source>Video(s) added to playlist</source>
+        <translation>Видео добавлено в плейлист</translation>
+    </message>
     <message>
         <location filename="../main.qml" line="219"/>
         <source>&apos; failed</source>
@@ -1505,12 +1518,12 @@
         <translation>Ошибка</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="416"/>
+        <location filename="../main.qml" line="417"/>
         <source>Most Recent</source>
         <translation>Последние</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="417"/>
+        <location filename="../main.qml" line="418"/>
         <source>Most Viewed</source>
         <translation>Популярные</translation>
     </message>
