@@ -23,7 +23,7 @@ void Sharing::setFacebookToken(const QString &token) {
 //    twitterSecret = secret;
 //}
 
-void Sharing::postToFacebook(const QString &videoId, const QString &message) {
+void Sharing::postToFacebook(const QString &videoId, const QString &title, const QString &description, const QString &message) {
     /* Helper method that posts HTTP POST requests */
 
     QByteArray id;
@@ -45,6 +45,8 @@ void Sharing::postToFacebook(const QString &videoId, const QString &message) {
             + "&link=" + playerUrl
             + "&source=" + embedUrl
             + "&picture=" + thumbUrl
+            + "&name=" + title.toAscii()
+            + "&description=" + description.toAscii()
             + "&attribution=via cuteTube on the Nokia N900";
 
 //    qDebug() << postData;
