@@ -9,7 +9,6 @@
 
 class QNetworkAccessManager;
 class QNetworkReply;
-class QNetworkRequest;
 
 class YouTube : public QObject {
     Q_OBJECT
@@ -46,6 +45,9 @@ public slots:
 
 private slots:
     void checkLogin();
+    void siteLogin();
+    void checkSiteLogin();
+    void checkAgeVerification();
     void setCurrentUser(const QString &user);
     void setAccessToken(const QByteArray &token);
     void setUploadUrl();
@@ -56,6 +58,7 @@ private slots:
     void deleteRequest(const QUrl &url);
     void postFinished();
     void parseVideoPage(QNetworkReply *reply);
+    void parseVideoPage();
 
 private:
     QNetworkAccessManager *nam;
